Class: AP

Inherits:
Object
  • Object
show all
Defined in:
lib/iwlist.rb

Overview

This is a class providing access to information about access points discovered by the IWList.scan() method.

Perhaps eventually I might put some useful methods here…

Instance Attribute Summary collapse

Instance Attribute Details

#addressObject

Returns the value of attribute address.



12
13
14
# File 'lib/iwlist.rb', line 12

def address
  @address
end

#bitratesObject

Returns the value of attribute bitrates.



12
13
14
# File 'lib/iwlist.rb', line 12

def bitrates
  @bitrates
end

#cellObject

Returns the value of attribute cell.



12
13
14
# File 'lib/iwlist.rb', line 12

def cell
  @cell
end

#channelObject

Returns the value of attribute channel.



12
13
14
# File 'lib/iwlist.rb', line 12

def channel
  @channel
end

#encryptedObject

Returns the value of attribute encrypted.



12
13
14
# File 'lib/iwlist.rb', line 12

def encrypted
  @encrypted
end

#essidObject

Returns the value of attribute essid.



12
13
14
# File 'lib/iwlist.rb', line 12

def essid
  @essid
end

#essid_indexObject

Returns the value of attribute essid_index.



12
13
14
# File 'lib/iwlist.rb', line 12

def essid_index
  @essid_index
end

#ieObject

Returns the value of attribute ie.



12
13
14
# File 'lib/iwlist.rb', line 12

def ie
  @ie
end

#last_beaconObject

Returns the value of attribute last_beacon.



12
13
14
# File 'lib/iwlist.rb', line 12

def last_beacon
  @last_beacon
end

#modeObject

Returns the value of attribute mode.



12
13
14
# File 'lib/iwlist.rb', line 12

def mode
  @mode
end

#noise_levelObject

Returns the value of attribute noise_level.



12
13
14
# File 'lib/iwlist.rb', line 12

def noise_level
  @noise_level
end

#protocolObject

Returns the value of attribute protocol.



12
13
14
# File 'lib/iwlist.rb', line 12

def protocol
  @protocol
end

#qualityObject

Returns the value of attribute quality.



12
13
14
# File 'lib/iwlist.rb', line 12

def quality
  @quality
end

#signal_levelObject

Returns the value of attribute signal_level.



12
13
14
# File 'lib/iwlist.rb', line 12

def signal_level
  @signal_level
end