Exception: InvalidInterface
- Inherits:
-
Exception
- Object
- Exception
- InvalidInterface
- Defined in:
- lib/iwlist.rb
Overview
This exception class is raised if the interface provided to IWList.scan isn’t in the form ethN or wlanN
This exception class is raised if the interface provided to IWList.scan isn’t in the form ethN or wlanN