Class: AP
- Inherits:
-
Object
- Object
- AP
- Defined in:
- lib/iwlist.rb
Overview
This is a class providing access to information about access points discovered by the IWList.scan() method.
Perhaps eventually I might put some useful methods here…
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#bitrates ⇒ Object
Returns the value of attribute bitrates.
-
#cell ⇒ Object
Returns the value of attribute cell.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#encrypted ⇒ Object
Returns the value of attribute encrypted.
-
#essid ⇒ Object
Returns the value of attribute essid.
-
#essid_index ⇒ Object
Returns the value of attribute essid_index.
-
#ie ⇒ Object
Returns the value of attribute ie.
-
#last_beacon ⇒ Object
Returns the value of attribute last_beacon.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#noise_level ⇒ Object
Returns the value of attribute noise_level.
-
#protocol ⇒ Object
Returns the value of attribute protocol.
-
#quality ⇒ Object
Returns the value of attribute quality.
-
#signal_level ⇒ Object
Returns the value of attribute signal_level.
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def address @address end |
#bitrates ⇒ Object
Returns the value of attribute bitrates.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def bitrates @bitrates end |
#cell ⇒ Object
Returns the value of attribute cell.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def cell @cell end |
#channel ⇒ Object
Returns the value of attribute channel.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def channel @channel end |
#encrypted ⇒ Object
Returns the value of attribute encrypted.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def encrypted @encrypted end |
#essid ⇒ Object
Returns the value of attribute essid.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def essid @essid end |
#essid_index ⇒ Object
Returns the value of attribute essid_index.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def essid_index @essid_index end |
#ie ⇒ Object
Returns the value of attribute ie.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def ie @ie end |
#last_beacon ⇒ Object
Returns the value of attribute last_beacon.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def last_beacon @last_beacon end |
#mode ⇒ Object
Returns the value of attribute mode.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def mode @mode end |
#noise_level ⇒ Object
Returns the value of attribute noise_level.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def noise_level @noise_level end |
#protocol ⇒ Object
Returns the value of attribute protocol.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def protocol @protocol end |
#quality ⇒ Object
Returns the value of attribute quality.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def quality @quality end |
#signal_level ⇒ Object
Returns the value of attribute signal_level.
12 13 14 |
# File 'lib/iwlist.rb', line 12 def signal_level @signal_level end |